![](https://raw.githubusercontent.com/Flask-Planet/Flask-BigApp/master/app/theme/static/img/Flask-BigApp-Logo-White-BG.png)

# Flask-BigApp

`pip install Flask-BigApp`

![Tests](https://github.com/CheeseCake87/Flask-BigApp/actions/workflows/tests.yml/badge.svg)

**What is Flask-BigApp?**

Flask-BigApp's main purpose is to help simplify the importing of blueprints, routes and models.
It has a few extra features built in to help with theming, securing pages and password authentication.

[Go to Wiki](https://github.com/CheeseCake87/Flask-BigApp/wiki)

If you'd like to jump stright in, here's a working example porject:

[TemPro-Flask-BigApp](https://github.com/Flask-Planet/TemPro-Flask-BigApp)
